/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2020 Victor Kirhenshtein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.nxmc.base.widgets.helpers;

import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableColumn;

/**
 * Table control column selection listener used to change sorting column
 */
public class TableSortingListener extends SelectionAdapter
{
	private TableViewer viewer;
	
	/**
	 * Constructor
	 */
	public TableSortingListener(TableViewer viewer)
	{
		this.viewer = viewer;
	}
	
   /**
    * @see org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse.swt.events.SelectionEvent)
    */
	@Override
	public void widgetSelected(SelectionEvent e)
	{
		Table table = viewer.getTable();
		TableColumn sortColumn = table.getSortColumn();
		if (sortColumn == (TableColumn)e.getSource())
		{
			table.setSortDirection(table.getSortDirection() == SWT.UP ? SWT.DOWN : SWT.UP);
		}
		else
		{
			table.setSortColumn((TableColumn)e.getSource());
		}
		viewer.refresh(false);
	}
}
